@@ -20,6 +20,4 @@ class HackerNews:
 			try:
 				return r.json()
 			except ValueError:
-				continue;
-			finally:
-				print i
\ No newline at end of file
+				continue;
\ No newline at end of file
